@@ -63,6 +63,7 @@ TextProcessor::TextProcessor(QWidget *parent) :
     connect(m_recipient->m_btSend,SIGNAL(clicked()),this,SLOT(sendSms()));
 
     m_smsEdit = ui->textEdit;
+    m_smsEdit->setReadOnly(true);
     m_phoneNumber = m_recipient->getPhoneNumberField();
 
     //Enabling scrolling
@@ -782,6 +783,10 @@ QPushButton* TextProcessor::getSendBt()
 /** Commit text to external app**/
 void TextProcessor::commit()
 {
+    parentWidget()->parentWidget()->hide();
+
+    sleep(0.1);
+
     QDBusMessage msg = QDBusMessage::createMethodCall(
             "it.rsc.fastsms.plugin.connection", // --dest
             "/", // destination object path
@@ -797,7 +802,6 @@ void TextProcessor::commit()
     //qDebug() << msg;
     bool ok = msg.type() != QDBusMessage::ErrorMessage;
 
-    parentWidget()->parentWidget()->hide();
     qDebug() << "Sended:" << msg;
     qDebug() << "Sending state:" << ok;
 
